You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@commons.apache.org by er...@apache.org on 2011/01/21 16:38:21 UTC

svn commit: r1061850 - in /commons/proper/math/trunk/src: main/java/org/apache/commons/math/ test/java/org/apache/commons/math/

Author: erans
Date: Fri Jan 21 15:38:21 2011
New Revision: 1061850

URL: http://svn.apache.org/viewvc?rev=1061850&view=rev
Log:
MATH-492
Removed class "MaxIterationsExceededException". Replaced last occurrence by
"MaxCountExceedeException".

Removed:
    commons/proper/math/trunk/src/main/java/org/apache/commons/math/MaxIterationsExceededException.java
    commons/proper/math/trunk/src/test/java/org/apache/commons/math/MaxIterationsExceededExceptionTest.java
Modified:
    commons/proper/math/trunk/src/main/java/org/apache/commons/math/ConvergingAlgorithmImpl.java

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math/ConvergingAlgorithmImpl.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math/ConvergingAlgorithmImpl.java?rev=1061850&r1=1061849&r2=1061850&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math/ConvergingAlgorithmImpl.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math/ConvergingAlgorithmImpl.java Fri Jan 21 15:38:21 2011
@@ -17,6 +17,8 @@
 
 package org.apache.commons.math;
 
+import org.apache.commons.math.exception.MaxCountExceededException;
+
 /**
  * Provide a default implementation for several functions useful to generic
  * converging algorithms.
@@ -143,14 +145,13 @@ public abstract class ConvergingAlgorith
     /**
      * Increment the iterations counter by 1.
      *
      * @throws MaxIterationsExceededException if the maximal number
      * of iterations is exceeded.
      * @since 2.2
      */
-    protected void incrementIterationsCounter()
-        throws MaxIterationsExceededException {
+    protected void incrementIterationsCounter() {
         if (++iterationCount > maximalIterationCount) {
-            throw new MaxIterationsExceededException(maximalIterationCount);
+            throw new MaxCountExceededException(maximalIterationCount);
         }
     }
 }
@@ -143,14 +145,13 @@ public abstract class ConvergingAlgorith
      * Increment the iterations counter by 1.
      *
-     * @throws MaxIterationsExceededException if the maximal number
+     * @throws MaxCountExceededException if the maximal number
      * of iterations is exceeded.
      * @since 2.2